@@ -1,7 +1,7 @@
 /* Accelerator stuff */
 
 /*
- * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2001, 2002 Havoc Pennington, Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -25,6 +25,7 @@
 #include <string.h>
 #include <glade/glade.h>
 #include "eggcellrendererkeys.h"
+#include "eggaccelerators.h"
 
 #define D(x)
 
@@ -43,6 +44,7 @@
 #define KEY_NEXT_TAB CONF_KEYS_PREFIX"/next_tab"
 #define KEY_SET_TERMINAL_TITLE CONF_KEYS_PREFIX"/set_window_title"
 #define PREFIX_KEY_SWITCH_TO_TAB CONF_KEYS_PREFIX"/switch_to_tab_"
+#define KEY_HELP CONF_KEYS_PREFIX"/help"
 
 typedef struct
 {
@@ -148,13 +150,18 @@ static KeyEntry go_entries[] =
     PREFIX_ACCEL_PATH_SWITCH_TO_TAB"12", 0, 0, NULL, FALSE }
 };
 
+static KeyEntry help_entries[] = {
+  { N_("Contents"), KEY_HELP, ACCEL_PATH_HELP, 0, 0, NULL, FALSE}
+};
+
 static KeyEntryList all_entries[] =
 {
   { file_entries, G_N_ELEMENTS (file_entries), N_("File") },
   { edit_entries, G_N_ELEMENTS (edit_entries), N_("Edit") },
   { view_entries, G_N_ELEMENTS (view_entries), N_("View") },
   { terminal_entries, G_N_ELEMENTS (terminal_entries), N_("Terminal") },
-  { go_entries, G_N_ELEMENTS (go_entries), N_("Go") }
+  { go_entries, G_N_ELEMENTS (go_entries), N_("Go") },
+  { help_entries, G_N_ELEMENTS (help_entries), N_("Help") }
 };
 
 enum
@@ -188,6 +195,11 @@ static void mnemonics_change_notify (GConfClient *client,
                                     GConfEntry  *entry,
                                     gpointer     user_data);
 
+static void menu_accels_change_notify (GConfClient *client,
+                                       guint        cnxn_id,
+                                       GConfEntry  *entry,
+                                       gpointer     user_data);
+
 static void accel_changed_callback (GtkAccelGroup  *accel_group,
                                     guint           keyval,
                                     GdkModifierType modifier,
@@ -208,13 +220,18 @@ static char*    binding_name        (guint            keyval,
 
 static void      queue_gconf_sync (void);
 
+static void      update_menu_accel_state (void);
+
 static GtkAccelGroup * /* accel_group_i_need_because_gtk_accel_api_sucks */ hack_group = NULL;
 static GConfClient *global_conf;
 static GSList *living_treeviews = NULL;
 static GSList *living_mnemonics_checkbuttons = NULL;
+static GSList *living_menu_accel_checkbuttons = NULL;
 static gboolean using_mnemonics = TRUE;
+static gboolean using_menu_accels = TRUE;
 /* never set gconf keys in response to receiving a gconf notify. */
 static int inside_gconf_notify = 0;
+static char *saved_menu_accel = NULL;
 
 void
 terminal_accels_init (GConfClient *conf)
@@ -346,6 +363,33 @@ terminal_accels_init (GConfClient *conf)
                   err->message);
       g_error_free (err);
     }
+
+  err = NULL;
+  using_menu_accels = gconf_client_get_bool (global_conf,
+                                             CONF_GLOBAL_PREFIX"/use_menu_accelerators",
+                                             &err);
+  if (err)
+    {
+      g_printerr (_("There was an error loading config value for whether to use menu accelerators. (%s)\n"),
+                  err->message);
+      g_error_free (err);
+    }
+
+  update_menu_accel_state ();
+  
+  err = NULL;
+  gconf_client_notify_add (conf,
+                           CONF_GLOBAL_PREFIX"/use_menu_accelerators",
+                           menu_accels_change_notify,
+                           NULL, /* user_data */
+                           NULL, &err);
+  
+  if (err)
+    {
+      g_printerr (_("There was an error subscribing to notification for use_menu_accelerators (%s)\n"),
+                  err->message);
+      g_error_free (err);
+    }
 }
 
 GtkAccelGroup*
@@ -556,11 +600,50 @@ mnemonics_change_notify (GConfClient *client,
     }
 }
 
+static void
+menu_accels_change_notify (GConfClient *client,
+                           guint        cnxn_id,
+                           GConfEntry  *entry,
+                           gpointer     user_data)
+{
+  GConfValue *val;
+  
+  val = gconf_entry_get_value (entry);  
+  
+  if (strcmp (gconf_entry_get_key (entry),
+              CONF_GLOBAL_PREFIX"/use_menu_accelerators") == 0)
+    {
+      if (val && val->type == GCONF_VALUE_BOOL)
+        {
+          if (using_menu_accels != gconf_value_get_bool (val))
+            {
+              GSList *tmp;
+              
+              using_menu_accels = !using_menu_accels;
+
+              /* Reset the checkbuttons */
+              tmp = living_menu_accel_checkbuttons;
+              while (tmp != NULL)
+                {
+                  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp->data),
+                                                !using_menu_accels);
+                  tmp = tmp->next;
+                }
+
+              /* Reset the actual feature; super broken hack alert */
+              update_menu_accel_state ();
+            }
+        }
+    }
+}
+
 static gboolean
 binding_from_string (const char      *str,
                      guint           *accelerator_key,
                      GdkModifierType *accelerator_mods)
 {
+  EggVirtualModifierType virtual;
+  
   g_return_val_if_fail (accelerator_key != NULL, FALSE);
   
   if (str == NULL || (str && strcmp (str, "disabled") == 0))
@@ -570,8 +653,20 @@ binding_from_string (const char      *str,
       return TRUE;
     }
 
-  gtk_accelerator_parse (str, accelerator_key, accelerator_mods);
+  if (!egg_accelerator_parse_virtual (str, accelerator_key, &virtual))
+    return FALSE;
 
+  egg_keymap_resolve_virtual_modifiers (gdk_keymap_get_default (),
+                                        virtual,
+                                        accelerator_mods);
+
+  /* Be sure the GTK accelerator system will be able to handle this
+   * accelerator. Be sure to allow no-accelerator accels like F1.
+   */
+  if ((*accelerator_mods & gtk_accelerator_get_default_mod_mask ()) == 0 &&
+      *accelerator_mods != 0)
+    return FALSE;
+  
   if (*accelerator_key == 0)
     return FALSE;
   else
@@ -807,6 +902,7 @@ accel_edited_callback (GtkCellRendererText *cell,
                        const char          *path_string,
                        guint                keyval,
                        GdkModifierType      mask,
+                       guint                hardware_keycode,
                        gpointer             data)
 {
   GtkTreeModel *model = (GtkTreeModel *)data;
@@ -877,6 +973,91 @@ disable_mnemonics_toggled (GtkWidget *button,
     }
 }
 
+static void
+disable_menu_accels_toggled (GtkWidget *button,
+                             gpointer   data)
+{
+  gboolean active;
+
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
+
+  /* I confused myself by making the visible button opposite
+   * the gconf key
+   */
+  if (active != (!using_menu_accels))
+    {
+      GError *err;
+      
+      err = NULL;
+      gconf_client_set_bool (global_conf,
+                             CONF_GLOBAL_PREFIX"/use_menu_accelerators",
+                             !active,
+                             &err);
+      if (err != NULL)
+        {
+          g_printerr (_("Error setting use_menu_accelerators key: %s\n"),
+                      err->message);
+          
+          g_error_free (err);
+        }
+    }
+}
+
+typedef struct
+{
+  GtkTreeView *tree_view;
+  GtkTreePath *path;
+} IdleData;
+
+static gboolean
+real_start_editing_cb (IdleData *idle_data)
+{
+  gtk_widget_grab_focus (GTK_WIDGET (idle_data->tree_view));
+  gtk_tree_view_set_cursor (idle_data->tree_view,
+                            idle_data->path,
+			    gtk_tree_view_get_column (idle_data->tree_view, 1),
+			    TRUE);
+
+  gtk_tree_path_free (idle_data->path);
+  g_free (idle_data);
+
+  return FALSE;
+}
+
+gboolean
+start_editing_cb (GtkTreeView    *tree_view,
+                  GdkEventButton *event,
+		  gpointer        data)
+{
+  GtkTreePath *path;
+
+  if (event->window != gtk_tree_view_get_bin_window (tree_view))
+    return FALSE;
+
+  if (gtk_tree_view_get_path_at_pos (tree_view,
+                                     (gint) event->x,
+				     (gint) event->y,
+				     &path, NULL,
+				     NULL, NULL))
+    {
+      IdleData *idle_data;
+
+      if (gtk_tree_path_get_depth (path) == 1)
+        {
+	  gtk_tree_path_free (path);
+	  return FALSE;
+	}
+
+      idle_data = g_new (IdleData, 1);
+      idle_data->tree_view = tree_view;
+      idle_data->path = path;
+      g_signal_stop_emission_by_name (G_OBJECT (tree_view), "button_press_event");
+      g_idle_add ((GSourceFunc) real_start_editing_cb, idle_data);
+    }
+
+  return TRUE;
+}
+
 GtkWidget*
 terminal_edit_keys_dialog_new (GtkWindow *transient_parent)
 {
@@ -943,18 +1124,28 @@ terminal_edit_keys_dialog_new (GtkWindow *transient_parent)
   g_signal_connect (G_OBJECT (w), "toggled",
                     G_CALLBACK (disable_mnemonics_toggled),
                     NULL);
+
+  w = glade_xml_get_widget (xml, "disable-menu-accel-checkbutton");
+  living_mnemonics_checkbuttons = g_slist_prepend (living_menu_accel_checkbuttons,
+                                                   w);
+  g_signal_connect (G_OBJECT (w), "destroy",
+                    G_CALLBACK (remove_from_list_callback),
+                    &living_menu_accel_checkbuttons);
+
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), !using_menu_accels);
+  g_signal_connect (G_OBJECT (w), "toggled",
+                    G_CALLBACK (disable_menu_accels_toggled),
+                    NULL);
   
   w = glade_xml_get_widget (xml, "accelerators-treeview");
 
   living_treeviews = g_slist_prepend (living_treeviews, w);
 
+  g_signal_connect (G_OBJECT (w), "button_press_event",
+		    G_CALLBACK (start_editing_cb), NULL);
   g_signal_connect (G_OBJECT (w), "destroy",
                     G_CALLBACK (remove_from_list_callback),
                     &living_treeviews);
-  
-  gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (w)),
-                               GTK_SELECTION_NONE);
-
 
   tree = gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
   
@@ -1033,3 +1224,36 @@ terminal_edit_keys_dialog_new (GtkWindow *transient_parent)
   
   return w;
 }
+
+static void
+update_menu_accel_state (void)
+{
+  /* Now this is a bad hack on so many levels. */
+  
+  if (saved_menu_accel == NULL)
+    {
+      g_object_get (G_OBJECT (gtk_settings_get_default ()),
+                    "gtk-menu-bar-accel",
+                    &saved_menu_accel,
+                    NULL);
+      /* FIXME if gtkrc is reparsed we don't catch on,
+       * I guess.
+       */
+    }
+  
+  if (using_menu_accels)
+    {
+      gtk_settings_set_string_property (gtk_settings_get_default (),
+                                        "gtk-menu-bar-accel",
+                                        saved_menu_accel,
+                                        "gnome-terminal");
+    }
+  else
+    {
+      gtk_settings_set_string_property (gtk_settings_get_default (),
+                                        "gtk-menu-bar-accel",
+                                        /* no one will ever press this ;-) */
+                                        "<Shift><Control><Mod1><Mod2><Mod3><Mod4><Mod5>F10",
+                                        "gnome-terminal");
+    }
+}
