@@ -270,7 +270,7 @@ int              terminal_profile_get_count              (void);
 /* may return NULL */
 TerminalProfile* terminal_profile_get_default            (void);
 /* never returns NULL if any profiles exist, one is always supposed to */
-TerminalProfile* terminal_profile_get_for_new_term       (void);
+TerminalProfile* terminal_profile_get_for_new_term       (TerminalProfile *current);
 TerminalProfile* terminal_profile_lookup                 (const char      *name);
 TerminalProfile* terminal_profile_lookup_by_visible_name (const char      *name);
 void             terminal_profile_forget                 (TerminalProfile *profile);
@@ -297,12 +297,6 @@ gboolean terminal_palette_from_string (const char     *str,
                                        gboolean        warn);
 
 
-/* Used to convert the double "darkness" setting into a bool.
- * Temporary hack.
- */
-#define DARKNESS_THRESHOLD 0.25
-#define DARKNESS_TRUE  0.5
-#define DARKNESS_FALSE 0.0
 
 G_END_DECLS
 
