@@ -73,7 +73,6 @@ static void terminal_screen_class_init  (TerminalScreenClass *klass);
 static void terminal_screen_finalize    (GObject             *object);
 static void terminal_screen_update_on_realize (GtkWidget      *widget,
                                                TerminalScreen *screen);
-
 static void     terminal_screen_popup_menu         (GtkWidget      *term,
                                                     TerminalScreen *screen);
 static gboolean terminal_screen_button_press_event (GtkWidget      *term,
@@ -140,6 +139,16 @@ terminal_screen_get_type (void)
   return object_type;
 }
 
+
+static void
+style_set_callback (GtkWidget *widget,
+                    GtkStyle  *previous_style,
+                    void      *data)
+{
+  if (GTK_WIDGET_REALIZED (widget))
+    terminal_screen_update_on_realize (widget, TERMINAL_SCREEN (data));  
+}
+
 static void
 terminal_screen_init (TerminalScreen *screen)
 {
@@ -176,6 +185,11 @@ terminal_screen_init (TerminalScreen *screen)
                     G_CALLBACK (terminal_screen_update_on_realize),
                     screen);
 
+  g_signal_connect (G_OBJECT (screen->priv->term),
+                    "style_set",
+                    G_CALLBACK (style_set_callback),
+                    screen);
+  
   g_signal_connect (G_OBJECT (screen->priv->term),
                     "popup_menu",
                     G_CALLBACK (terminal_screen_popup_menu),
@@ -209,7 +223,7 @@ terminal_screen_class_init (TerminalScreenClass *klass)
   parent_class = g_type_class_peek_parent (klass);
   
   object_class->finalize = terminal_screen_finalize;
-
+  
   signals[PROFILE_SET] =
     g_signal_new ("profile_set",
                   G_OBJECT_CLASS_TYPE (object_class),
@@ -625,7 +639,7 @@ profile_forgotten_callback (TerminalProfile *profile,
   TerminalProfile *new_profile;
 
   /* Revert to the new term profile if any */
-  new_profile = terminal_profile_get_for_new_term ();
+  new_profile = terminal_profile_get_for_new_term (NULL);
 
   if (new_profile)
     terminal_screen_set_profile (screen, new_profile);
@@ -805,7 +819,7 @@ get_child_command (TerminalScreen *screen,
   else
     {
       const char *only_name;
-      const char *shell;
+      char *shell;
 
       shell = gnome_util_user_shell ();
 
@@ -959,7 +973,7 @@ new_window_callback (GtkWidget      *menu_item,
                      TerminalScreen *screen)
 {
   terminal_app_new_terminal (terminal_app_get (),
-                             terminal_profile_get_for_new_term (),
+                             terminal_profile_get_for_new_term (screen->priv->profile),
                              NULL,
                              FALSE, FALSE, NULL, NULL, NULL, NULL);
 }
@@ -969,7 +983,7 @@ new_tab_callback (GtkWidget      *menu_item,
                   TerminalScreen *screen)
 {
   terminal_app_new_terminal (terminal_app_get (),
-                             terminal_profile_get_for_new_term (),
+                             terminal_profile_get_for_new_term (screen->priv->profile),
                              screen->priv->window,
                              FALSE, FALSE, NULL, NULL, NULL, NULL);
 }
@@ -1971,14 +1985,14 @@ terminal_screen_setup_dnd (TerminalScreen *screen)
                      GDK_ACTION_COPY);
 }
 
-/* Indices of some xlfd string entries.  The first entry is 0 */
-#define XLFD_WEIGHT_INDEX			2
-#define XLFD_SLANT_INDEX			3
-#define XLFD_SIZE_IN_PIXELS_INDEX		6
-#define XLFD_SIZE_IN_POINTS_INDEX		7
-#define XLFD_HORIZONTAL_RESOLUTION_INDEX	8
-#define XLFD_VERTICAL_RESOLUTION_INDEX		9
-#define XLFD_SPACING_INDEX		        10
+/* Indices of some xlfd string entries.  The first entry is 1 */
+#define XLFD_WEIGHT_INDEX			3
+#define XLFD_SLANT_INDEX			4	
+#define XLFD_SIZE_IN_PIXELS_INDEX		7	
+#define XLFD_SIZE_IN_POINTS_INDEX		8	
+#define XLFD_HORIZONTAL_RESOLUTION_INDEX	9	
+#define XLFD_VERTICAL_RESOLUTION_INDEX		10	
+#define XLFD_SPACING_INDEX		        11
 
 #define XLFD_N_FIELDS 14
 
@@ -2098,7 +2112,7 @@ make_xfont_have_size_from_other_font (const char *fontname,
 
   ret = NULL;
   size_pixels = xlfd_get_nth_field (other_font, XLFD_SIZE_IN_PIXELS_INDEX);
-  size_points = xlfd_get_nth_field (other_font, XLFD_SIZE_IN_PIXELS_INDEX);
+  size_points = xlfd_get_nth_field (other_font, XLFD_SIZE_IN_POINTS_INDEX);
 
   if (size_pixels && size_points)
     {
@@ -2134,9 +2148,8 @@ make_font_monospace (const PangoFontDescription *font)
   
   ret = pango_font_description_copy (font);
 
-  /* FIXME use a heuristic here such as getting width of "i" and
-   * "M" and if they match our font is monospace.
-   */
+  /* FIXME */
+  pango_font_description_set_family (ret, "monospace");
   
   return ret;
 }
