@@ -101,9 +101,7 @@ terminal_widget_get_padding                (GtkWidget            *widget,
 					    int                  *xpad,
 					    int                  *ypad)
 {
-  /* We don't do padding! */
-  *xpad = 0;
-  *ypad = 0;
+  vte_terminal_get_padding(VTE_TERMINAL(widget), xpad, ypad);
 }
 
 void
@@ -432,7 +430,8 @@ terminal_widget_fork_command (GtkWidget   *widget,
                               int         *child_pid,
 			      GError     **err)
 {
-  *child_pid = vte_terminal_fork_command (VTE_TERMINAL (widget), path, argv);
+  *child_pid = vte_terminal_fork_command (VTE_TERMINAL (widget),
+		 			  path, argv, envp);
   return (*child_pid != -1);
 }
 
