@@ -31,6 +31,7 @@
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <gdk/gdkx.h>
+#include <gdk/gdkkeysyms.h>
 #include <eel/eel-ellipsizing-label.h>
 
 struct _TerminalWindowPrivate
@@ -46,6 +47,7 @@ struct _TerminalWindowPrivate
   GtkWidget *help_menuitem;
   GtkWidget *new_window_menuitem;
   GtkWidget *new_tab_menuitem;
+  GtkWidget *close_tab_menuitem;
   GtkWidget *copy_menuitem;
   GtkWidget *paste_menuitem;
   GtkWidget *fullscreen_menuitem;
@@ -324,13 +326,22 @@ fill_in_new_term_submenus (TerminalWindow *window)
   GSList *group;
   GtkAccelGroup *accel_group;
   char *str;
-  TerminalProfile *default_profile;
+  TerminalProfile *current_profile;
   int i;
-  
-  default_profile = terminal_profile_get_default ();
 
-  if (default_profile == NULL)
+  current_profile = NULL;
+  if (window->priv->active_term != NULL)
+    current_profile = terminal_screen_get_profile (window->priv->active_term);
+
+  /* if current_profile is null, this will change it to a default,
+   * otherwise do nothing
+   */
+  current_profile = terminal_profile_get_for_new_term (current_profile);
+  
+  if (current_profile == NULL)
     {
+      /* Well, this shouldn't happen */
+      
       gtk_widget_set_sensitive (window->priv->new_window_menuitem, FALSE);
       gtk_menu_item_set_submenu (GTK_MENU_ITEM (window->priv->new_window_menuitem),
                                  NULL);
@@ -341,7 +352,7 @@ fill_in_new_term_submenus (TerminalWindow *window)
       return;      
     }
 
-  str = g_strdup (terminal_profile_get_visible_name (default_profile));
+  str = g_strdup (terminal_profile_get_visible_name (current_profile));
   
   gtk_widget_set_sensitive (window->priv->new_window_menuitem, TRUE);
   gtk_widget_set_sensitive (window->priv->new_tab_menuitem, TRUE);
@@ -362,10 +373,10 @@ fill_in_new_term_submenus (TerminalWindow *window)
   g_signal_connect (G_OBJECT (menu_item),
                     "activate",
                     G_CALLBACK (new_window_callback), window);
-  g_object_ref (G_OBJECT (default_profile));
+  g_object_ref (G_OBJECT (current_profile));
   g_object_set_data_full (G_OBJECT (menu_item),
                           "profile",
-                          default_profile,
+                          current_profile,
                           (GDestroyNotify) g_object_unref);  
 
   gtk_menu_item_set_accel_path (GTK_MENU_ITEM (menu_item),
@@ -391,10 +402,10 @@ fill_in_new_term_submenus (TerminalWindow *window)
   g_signal_connect (G_OBJECT (menu_item),
                     "activate",
                     G_CALLBACK (new_tab_callback), window);
-  g_object_ref (G_OBJECT (default_profile));
+  g_object_ref (G_OBJECT (current_profile));
   g_object_set_data_full (G_OBJECT (menu_item),
                           "profile",
-                          default_profile,
+                          current_profile,
                           (GDestroyNotify) g_object_unref);
 
   gtk_menu_item_set_accel_path (GTK_MENU_ITEM (menu_item),
@@ -543,9 +554,10 @@ terminal_window_init (TerminalWindow *window)
                    G_CALLBACK (close_window_callback),
                    window);
   
-  append_menuitem (menu, _("C_lose Tab"), ACCEL_PATH_CLOSE_TAB,
-                   G_CALLBACK (close_tab_callback),
-                   window);
+  window->priv->close_tab_menuitem = 
+    append_menuitem (menu, _("C_lose Tab"), ACCEL_PATH_CLOSE_TAB,
+                     G_CALLBACK (close_tab_callback),
+                     window);
   
   mi = append_menuitem (window->priv->menubar,
                         "", NULL,
@@ -656,11 +668,16 @@ terminal_window_init (TerminalWindow *window)
 
   mi = append_stock_menuitem (menu, GTK_STOCK_HELP, NULL,
 			      G_CALLBACK (help_callback), window);
-  set_menuitem_text (mi, _("_Help Contents"), FALSE);
+  set_menuitem_text (mi, _("_Contents"), FALSE);
+
+  gtk_accel_map_add_entry (ACCEL_PATH_HELP, GDK_F1, 0);
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (mi),
+                                ACCEL_PATH_HELP);
+
   
   mi = append_stock_menuitem (menu, GNOME_STOCK_ABOUT, NULL,
                               G_CALLBACK (about_callback), window);
-  set_menuitem_text (mi, _("_About GNOME Terminal"),
+  set_menuitem_text (mi, _("_About"),
                      FALSE);
 
   terminal_window_reread_profile_list (window);
@@ -808,6 +825,8 @@ profile_set_callback (TerminalScreen *screen,
 {
   /* Redo the pick-a-profile menu */
   fill_in_config_picker_submenu (window);
+  /* and the open-new-profile menu */
+  fill_in_new_term_submenus (window);
 }
 
 static void
@@ -857,11 +876,18 @@ update_tab_sensitivity (TerminalWindow *window)
   gtk_widget_set_sensitive (window->priv->previous_tab_menuitem,
                             page_num > 0);
 
+
   /* FIXME
    * http://bugzilla.gnome.org/show_bug.cgi?id=73229
    */
   on_last_page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
                                             page_num + 1) == NULL;
+
+  /* If there's only one tab, Close Tab is insensitive */
+  if (page_num == 0 && on_last_page)
+    gtk_widget_set_sensitive (window->priv->close_tab_menuitem, FALSE);
+  else
+    gtk_widget_set_sensitive (window->priv->close_tab_menuitem, TRUE);
   
   gtk_widget_set_sensitive (window->priv->next_tab_menuitem,
                             !on_last_page);
@@ -1237,6 +1263,7 @@ terminal_window_set_active (TerminalWindow *window,
   gtk_widget_grab_focus (terminal_screen_get_widget (window->priv->active_term));
 
   fill_in_config_picker_submenu (window);
+  fill_in_new_term_submenus (window);
 }
 
 TerminalScreen*
@@ -2106,13 +2133,17 @@ static void
 default_profile_changed (TerminalProfile    *profile,
                          TerminalSettingMask mask,
                          void               *data)
-{  
+{
+  /* This no longer applies, since our "new window" item
+   * is based on the current profile, not the default profile
+   */
+#if 0
   if (mask & TERMINAL_SETTING_IS_DEFAULT)
     {
       TerminalWindow *window;
 
       window = TERMINAL_WINDOW (data);
-
+      
       /* When the default changes, we get a settings change
        * on the old default and the new. We only rebuild
        * the menu on the notify for the new default.
@@ -2120,6 +2151,7 @@ default_profile_changed (TerminalProfile    *profile,
       if (terminal_profile_get_is_default (profile))
         fill_in_new_term_submenus (window);
     }
+#endif
 }
 
 static void
