@@ -79,6 +79,7 @@ static GConfClient *conf = NULL;
 static TerminalApp *app = NULL;
 static gboolean terminal_factory_disabled = FALSE;
 
+#define TERMINAL_STOCK_EDIT "terminal-edit"
 typedef struct
 {
   GList *initial_windows;
@@ -135,7 +136,7 @@ enum {
   OPTION_WINDOW_WITH_PROFILE_ID,
   OPTION_TAB_WITH_PROFILE_ID,
   OPTION_SHOW_MENUBAR,
-  OPTION_TOGGLE_MENUBAR,
+  OPTION_HIDE_MENUBAR,
   OPTION_GEOMETRY,
   OPTION_DISABLE_FACTORY,
   OPTION_TITLE,
@@ -148,7 +149,7 @@ struct poptOption options[] = {
   {
     NULL, 
     '\0', 
-    POPT_ARG_CALLBACK,
+    POPT_ARG_CALLBACK | POPT_CBFLAG_POST,
     parse_options_callback, 
     0, 
     NULL, 
@@ -222,7 +223,7 @@ struct poptOption options[] = {
     '\0',
     POPT_ARG_NONE,
     NULL,
-    OPTION_TOGGLE_MENUBAR,
+    OPTION_HIDE_MENUBAR,
     N_("Turn off the menubar for the last-specified window; applies to only one window; can be specified once for each window you create from the command line."),
     NULL
   },
@@ -526,24 +527,60 @@ initial_window_free (InitialWindow *iw)
   g_free (iw);
 }
 
-static InitialTab*
-ensure_top_tab (GList **initial_windows_p)
+static void
+apply_defaults (OptionParsingResults *results,
+                InitialWindow        *iw)
+{
+  g_assert (iw->geometry == NULL);
+
+  if (results->default_geometry)
+    {
+      iw->geometry = results->default_geometry;
+      results->default_geometry = NULL;
+    }
+
+  if (results->default_window_menubar_forced)
+    {
+      iw->force_menubar_state = TRUE;
+      iw->menubar_state = results->default_window_menubar_state;
+
+      results->default_window_menubar_forced = FALSE;
+    }
+}
+
+static InitialWindow*
+ensure_top_window (OptionParsingResults *results)
 {
   InitialWindow *iw;
-  InitialTab *it;
   
-  if (*initial_windows_p == NULL)
+  if (results->initial_windows == NULL)
     {
       iw = initial_window_new (NULL, FALSE);
-      *initial_windows_p = g_list_append (*initial_windows_p, iw);
+      apply_defaults (results, iw);
+
+      results->initial_windows = g_list_append (results->initial_windows,
+                                                iw);
     }
   else
     {
-      iw = g_list_last (*initial_windows_p)->data;
+      iw = g_list_last (results->initial_windows)->data;
     }
 
   g_assert (iw->tabs);
   
+  return iw;
+}
+
+static InitialTab*
+ensure_top_tab (OptionParsingResults *results)
+{
+  InitialWindow *iw;
+  InitialTab *it;
+
+  iw = ensure_top_window (results);
+
+  g_assert (iw->tabs);
+  
   it = g_list_last (iw->tabs)->data;
 
   return it;
@@ -577,6 +614,22 @@ set_default_icon (const char *filename)
   g_object_unref (G_OBJECT (pixbuf));
 }
 
+static InitialWindow*
+add_new_window (OptionParsingResults *results,
+                const char           *profile,
+                gboolean              is_id)
+{
+  InitialWindow *iw;
+
+  iw = initial_window_new (profile, is_id);
+  
+  apply_defaults (results, iw);
+
+  results->initial_windows = g_list_append (results->initial_windows, iw);
+  
+  return iw;
+}
+
 static void
 parse_options_callback (poptContext              ctx,
                         enum poptCallbackReason  reason,
@@ -587,8 +640,16 @@ parse_options_callback (poptContext              ctx,
   OptionParsingResults *results;
 
   results = data;
-  
-  if (reason != POPT_CALLBACK_REASON_OPTION)
+
+  if (reason == POPT_CALLBACK_REASON_POST)
+    {
+      /* Make sure we have some window */
+      if (results->initial_windows == NULL)
+        ensure_top_window (results);
+
+      return;
+    }
+  else if (reason != POPT_CALLBACK_REASON_OPTION)
     return;
 
   switch (opt->val & POPT_ARG_MASK)
@@ -618,7 +679,7 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it = ensure_top_tab (&results->initial_windows);
+        it = ensure_top_tab (results);
 
         if (it->exec_argv != NULL)
           {
@@ -640,7 +701,7 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it = ensure_top_tab (&results->initial_windows);
+        it = ensure_top_tab (results);
 
         if (it->exec_argv != NULL)
           {
@@ -666,11 +727,9 @@ parse_options_callback (poptContext              ctx,
             g_printerr (_("Option --window-with-profile requires an argument specifying what profile to use\n"));
             exit (1);
           }
-            
-        iw = initial_window_new (prof,
-                                 opt->val == OPTION_WINDOW_WITH_PROFILE_ID);
-          
-        results->initial_windows = g_list_append (results->initial_windows, iw);
+
+        iw = add_new_window (results, prof,
+                             opt->val == OPTION_WINDOW_WITH_PROFILE_ID);
       }
       break;
 
@@ -687,19 +746,20 @@ parse_options_callback (poptContext              ctx,
             g_printerr (_("Option --tab-with-profile requires an argument specifying what profile to use\n"));
             exit (1);
           }
-            
+
+                
         if (results->initial_windows)
           {
             iw = g_list_last (results->initial_windows)->data;
+
             iw->tabs = g_list_append (iw->tabs,
                                       initial_tab_new (prof,
                                                        opt->val == OPTION_TAB_WITH_PROFILE_ID));
           }
         else
           {
-            iw = initial_window_new (prof,
-                                     opt->val == OPTION_TAB_WITH_PROFILE_ID);
-            results->initial_windows = g_list_append (results->initial_windows, iw);
+            iw = add_new_window (results, prof, 
+                                 opt->val == OPTION_TAB_WITH_PROFILE_ID);
           }
       }
       break;
@@ -730,7 +790,7 @@ parse_options_callback (poptContext              ctx,
       }
       break;
           
-    case OPTION_TOGGLE_MENUBAR:
+    case OPTION_HIDE_MENUBAR:
       {
         InitialWindow *iw;
             
@@ -740,7 +800,7 @@ parse_options_callback (poptContext              ctx,
 
             if (iw->force_menubar_state)
               {
-                g_printerr (_("--show-menubar option given twice for the same window\n"));
+                g_printerr (_("--hide-menubar option given twice for the same window\n"));
 
                 exit (1);
               }
@@ -812,7 +872,7 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it = ensure_top_tab (&results->initial_windows);
+        it = ensure_top_tab (results);
 
         if (it->title)
           {
@@ -837,7 +897,7 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it = ensure_top_tab (&results->initial_windows);
+        it = ensure_top_tab (results);
 
         if (it->working_dir)
           {
@@ -936,10 +996,7 @@ static int
 new_terminal_with_options (OptionParsingResults *results)
 {
   GList *tmp;
-  int init_windows;
-
-  init_windows = g_list_length (app->windows);
-
+  
   tmp = results->initial_windows;
   while (tmp != NULL)
     {
@@ -965,13 +1022,17 @@ new_terminal_with_options (OptionParsingResults *results)
               else                
                 profile = terminal_profile_lookup_by_visible_name (it->profile);
             }
+          else if (it->profile == NULL)
+            {
+              profile = terminal_profile_get_for_new_term (NULL);
+            }
           
           if (profile == NULL)
             {
               if (it->profile)
                 g_printerr (_("No such profile '%s', using default profile\n"),
                             it->profile);
-              profile = terminal_profile_get_for_new_term ();
+              profile = terminal_profile_get_for_new_term (NULL);
             }
           
           g_assert (profile);
@@ -1008,28 +1069,6 @@ new_terminal_with_options (OptionParsingResults *results)
       tmp = tmp->next;
     }
 
-  if (g_list_length (app->windows) <= init_windows)
-    {
-      /* Open a default terminal */      
-
-      terminal_app_new_terminal (app,
-                                 terminal_profile_get_for_new_term (),
-                                 NULL,
-                                 results->default_window_menubar_forced,
-                                 results->default_window_menubar_state,
-                                 NULL,
-                                 results->default_geometry,
-                                 NULL,
-                                 NULL);
-    }
-  else
-    {
-      if (results->default_geometry)
-        {
-          g_printerr (_("--geometry given prior to options that create a new window, must be given after\n"));
-          return 1;
-        }
-    }
   return 0;
 }
 
@@ -1104,7 +1143,7 @@ main (int argc, char **argv)
                   *args);
       return 1;
     }
-
+  
   if (!terminal_factory_disabled)
     {
       if (terminal_invoke_factory (argc_copy, argv_copy))
@@ -1649,7 +1688,7 @@ terminal_app_new_profile (TerminalApp     *app,
       old_transient_parent = NULL;      
       
       app->new_profile_dialog =
-        gtk_dialog_new_with_buttons (_("New terminal profile"),
+        gtk_dialog_new_with_buttons (_("New Profile"),
                                      NULL,
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_STOCK_CANCEL,
@@ -1679,7 +1718,7 @@ terminal_app_new_profile (TerminalApp     *app,
       
       hbox = gtk_hbox_new (FALSE, PADDING);
 
-      label = gtk_label_new_with_mnemonic (_("Profile _Name:"));
+      label = gtk_label_new_with_mnemonic (_("Profile _name:"));
       gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
       entry = gtk_entry_new ();
       app->new_profile_name_entry = entry;
@@ -1698,7 +1737,7 @@ terminal_app_new_profile (TerminalApp     *app,
       
       hbox = gtk_hbox_new (FALSE, PADDING);
 
-      label = gtk_label_new_with_mnemonic (_("_Base new profile on:"));
+      label = gtk_label_new_with_mnemonic (_("_Base on:"));
       gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
       app->new_profile_base_menu = profile_optionmenu_new ();
       option_menu = app->new_profile_base_menu;
@@ -1990,19 +2029,19 @@ profile_list_delete_selection (GtkWidget   *profile_list,
                                    GTK_BUTTONS_NONE,
                                    "%s", 
                                    str->str);
-
   g_string_free (str, TRUE);
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-                          _("_No"),
+                          GTK_STOCK_CANCEL,
                           GTK_RESPONSE_REJECT,
-                          _("_Delete"),
+			  GTK_STOCK_DELETE,
                           GTK_RESPONSE_ACCEPT,
                           NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog),
-                                   GTK_RESPONSE_REJECT);
-  
+                                   GTK_RESPONSE_ACCEPT);
+ 
+  gtk_window_set_title (GTK_WINDOW (dialog), _("Delete Profile")); 
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
   g_object_set_data_full (G_OBJECT (dialog), "deleted-profiles-list",
@@ -2245,6 +2284,29 @@ manage_profiles_response_cb (GtkDialog *dialog,
     }
 }
 
+static void
+terminal_app_register_stock (void)
+{
+  static gboolean registered = FALSE;
+
+  if (!registered)
+    {
+      GtkIconFactory *factory;
+      GtkIconSet     *icons;
+
+      static GtkStockItem edit_item [] = {
+	{ TERMINAL_STOCK_EDIT, N_("_Edit"), 0, 0, GETTEXT_PACKAGE },
+      };
+
+      icons = gtk_icon_factory_lookup_default (GTK_STOCK_PREFERENCES);
+      factory = gtk_icon_factory_new ();
+      gtk_icon_factory_add (factory, TERMINAL_STOCK_EDIT, icons);
+      gtk_icon_factory_add_default (factory);
+      gtk_stock_add_static (edit_item, 1);
+      registered = TRUE;
+    }
+}
+
 void
 terminal_app_manage_profiles (TerminalApp     *app,
                               GtkWindow       *transient_parent)
@@ -2266,7 +2328,7 @@ terminal_app_manage_profiles (TerminalApp     *app,
       old_transient_parent = NULL;      
       
       app->manage_profiles_dialog =
-        gtk_dialog_new_with_buttons (_("Manage terminal profiles"),
+        gtk_dialog_new_with_buttons (_("Edit Profiles"),
                                      NULL,
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_STOCK_HELP,
@@ -2369,7 +2431,7 @@ terminal_app_manage_profiles (TerminalApp     *app,
       gtk_box_pack_start (GTK_BOX (vbox),
                           spacer, FALSE, FALSE, 0);
       
-      button = gtk_button_new_from_stock (_("_New..."));
+      button = gtk_button_new_from_stock (GTK_STOCK_NEW);
       fix_button_align (button);
       gtk_box_pack_start (GTK_BOX (vbox),
                           button, FALSE, FALSE, 0);
@@ -2379,8 +2441,10 @@ terminal_app_manage_profiles (TerminalApp     *app,
       terminal_util_set_atk_name_description (app->manage_profiles_new_button, NULL,                             
                                               _("Click to open new profile dialog"));
 
+
+      terminal_app_register_stock ();
       
-      button = gtk_button_new_with_mnemonic (_("_Edit..."));
+      button = gtk_button_new_from_stock (TERMINAL_STOCK_EDIT);
       fix_button_align (button);
       gtk_box_pack_start (GTK_BOX (vbox),
                           button, FALSE, FALSE, 0);
@@ -2390,7 +2454,7 @@ terminal_app_manage_profiles (TerminalApp     *app,
       terminal_util_set_atk_name_description (app->manage_profiles_edit_button, NULL,                            
                                               _("Click to open edit profile dialog"));
       
-      button = gtk_button_new_with_mnemonic (_("_Delete..."));
+      button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
       fix_button_align (button);
       gtk_box_pack_start (GTK_BOX (vbox),
                           button, FALSE, FALSE, 0);
@@ -2806,7 +2870,6 @@ terminal_new_event (BonoboListener    *listener,
 		    CORBA_Environment *ev,
 		    gpointer           user_data)
 {
-  int i;
   int argc;
   int nextopt;
   poptContext ctx;
